@@ -21,9 +21,9 @@ class LineMessage:
         self.contentType = message.contentType
         self.contentPreview = message.contentPreview
         self.contentMetadata = message.contentMetadata
-
-        self.sender   = client.getContactOrGroupById(message._from)
-        self.receiver = client.getContactOrGroupById(message.to)
+        
+        self.sender   = client.getContactOrRoomOrGroupById(message._from)
+        self.receiver = client.getContactOrRoomOrGroupById(message.to)
 
         # toType
         # 0: User
@@ -166,7 +166,16 @@ class LineGroup(LineBase):
 
     >>> group = LineGroup(client, client.groups[0])
     """
-    def __init__(self, client, group, is_joined=True):
+
+    id        = None
+    name      = None
+    is_joined = True
+
+    creator = None
+    members = []
+    invitee = []
+
+    def __init__(self, client, group=None, is_joined=True):
         """LineGroup init
 
         :param client: LineClient instance
@@ -174,7 +183,6 @@ class LineGroup(LineBase):
         :param is_joined: is a user joined or invited to a group
         """
 
-        self._client = client
         self._group  = group
 
         self.id      = group.id
